==> zio-aws-kinesisanalytics_2.13-5.17.113.1-sources.jar: zio/aws/kinesisanalytics/model/InputSchemaUpdate.scala <==
package zio.aws.kinesisanalytics.model
import zio.aws.kinesisanalytics.model.primitives.RecordEncoding
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class InputSchemaUpdate(
    recordFormatUpdate: Option[zio.aws.kinesisanalytics.model.RecordFormat] =
      None,
    recordEncodingUpdate: Option[RecordEncoding] = None,
    recordColumnUpdates: Option[
      Iterable[zio.aws.kinesisanalytics.model.RecordColumn]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate = {
    import InputSchemaUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate
      .builder()
      .optionallyWith(recordFormatUpdate.map(value => value.buildAwsValue()))(
        _.recordFormatUpdate
      )
      .optionallyWith(
        recordEncodingUpdate.map(value =>
          RecordEncoding.unwrap(value): java.lang.String
        )
      )(_.recordEncodingUpdate)
      .optionallyWith(
        recordColumnUpdates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.recordColumnUpdates)
      .build()
  }
  def asReadOnly: zio.aws.kinesisanalytics.model.InputSchemaUpdate.ReadOnly =
    zio.aws.kinesisanalytics.model.InputSchemaUpdate.wrap(buildAwsValue())
}
object InputSchemaUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalytics.model.InputSchemaUpdate =
      zio.aws.kinesisanalytics.model.InputSchemaUpdate(
        recordFormatUpdate.map(value => value.asEditable),
        recordEncodingUpdate.map(value => value),
        recordColumnUpdates.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def recordFormatUpdate
        : Option[zio.aws.kinesisanalytics.model.RecordFormat.ReadOnly]
    def recordEncodingUpdate: Option[RecordEncoding]
    def recordColumnUpdates
        : Option[List[zio.aws.kinesisanalytics.model.RecordColumn.ReadOnly]]
    def getRecordFormatUpdate: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalytics.model.RecordFormat.ReadOnly
    ] = AwsError.unwrapOptionField("recordFormatUpdate", recordFormatUpdate)
    def getRecordEncodingUpdate: ZIO[Any, AwsError, RecordEncoding] =
      AwsError.unwrapOptionField("recordEncodingUpdate", recordEncodingUpdate)
    def getRecordColumnUpdates: ZIO[Any, AwsError, List[
      zio.aws.kinesisanalytics.model.RecordColumn.ReadOnly
    ]] = AwsError.unwrapOptionField("recordColumnUpdates", recordColumnUpdates)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate
  ) extends zio.aws.kinesisanalytics.model.InputSchemaUpdate.ReadOnly {
    override val recordFormatUpdate
        : Option[zio.aws.kinesisanalytics.model.RecordFormat.ReadOnly] = scala
      .Option(impl.recordFormatUpdate())
      .map(value => zio.aws.kinesisanalytics.model.RecordFormat.wrap(value))
    override val recordEncodingUpdate: Option[RecordEncoding] = scala
      .Option(impl.recordEncodingUpdate())
      .map(value =>
        zio.aws.kinesisanalytics.model.primitives.RecordEncoding(value)
      )
    override val recordColumnUpdates
        : Option[List[zio.aws.kinesisanalytics.model.RecordColumn.ReadOnly]] =
      scala
        .Option(impl.recordColumnUpdates())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.kinesisanalytics.model.RecordColumn.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate
  ): zio.aws.kinesisanalytics.model.InputSchemaUpdate.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-kinesisanalytics_2.13-7.21.15.4-sources.jar: zio/aws/kinesisanalytics/model/InputSchemaUpdate.scala <==
package zio.aws.kinesisanalytics.model
import zio.aws.kinesisanalytics.model.primitives.RecordEncoding
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InputSchemaUpdate(
    recordFormatUpdate: Optional[zio.aws.kinesisanalytics.model.RecordFormat] =
      Optional.Absent,
    recordEncodingUpdate: Optional[RecordEncoding] = Optional.Absent,
    recordColumnUpdates: Optional[
      Iterable[zio.aws.kinesisanalytics.model.RecordColumn]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate = {
    import InputSchemaUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate
      .builder()
      .optionallyWith(recordFormatUpdate.map(value => value.buildAwsValue()))(
        _.recordFormatUpdate
      )
      .optionallyWith(
        recordEncodingUpdate.map(value =>
          RecordEncoding.unwrap(value): java.lang.String
        )
      )(_.recordEncodingUpdate)
      .optionallyWith(
        recordColumnUpdates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.recordColumnUpdates)
      .build()
  }
  def asReadOnly: zio.aws.kinesisanalytics.model.InputSchemaUpdate.ReadOnly =
    zio.aws.kinesisanalytics.model.InputSchemaUpdate.wrap(buildAwsValue())
}
object InputSchemaUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalytics.model.InputSchemaUpdate =
      zio.aws.kinesisanalytics.model.InputSchemaUpdate(
        recordFormatUpdate.map(value => value.asEditable),
        recordEncodingUpdate.map(value => value),
        recordColumnUpdates.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def recordFormatUpdate
        : Optional[zio.aws.kinesisanalytics.model.RecordFormat.ReadOnly]
    def recordEncodingUpdate: Optional[RecordEncoding]
    def recordColumnUpdates
        : Optional[List[zio.aws.kinesisanalytics.model.RecordColumn.ReadOnly]]
    def getRecordFormatUpdate: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalytics.model.RecordFormat.ReadOnly
    ] = AwsError.unwrapOptionField("recordFormatUpdate", recordFormatUpdate)
    def getRecordEncodingUpdate: ZIO[Any, AwsError, RecordEncoding] =
      AwsError.unwrapOptionField("recordEncodingUpdate", recordEncodingUpdate)
    def getRecordColumnUpdates: ZIO[Any, AwsError, List[
      zio.aws.kinesisanalytics.model.RecordColumn.ReadOnly
    ]] = AwsError.unwrapOptionField("recordColumnUpdates", recordColumnUpdates)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate
  ) extends zio.aws.kinesisanalytics.model.InputSchemaUpdate.ReadOnly {
    override val recordFormatUpdate
        : Optional[zio.aws.kinesisanalytics.model.RecordFormat.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.recordFormatUpdate())
        .map(value => zio.aws.kinesisanalytics.model.RecordFormat.wrap(value))
    override val recordEncodingUpdate: Optional[RecordEncoding] =
      zio.aws.core.internal
        .optionalFromNullable(impl.recordEncodingUpdate())
        .map(value =>
          zio.aws.kinesisanalytics.model.primitives.RecordEncoding(value)
        )
    override val recordColumnUpdates
        : Optional[List[zio.aws.kinesisanalytics.model.RecordColumn.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.recordColumnUpdates())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.kinesisanalytics.model.RecordColumn.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputSchemaUpdate
  ): zio.aws.kinesisanalytics.model.InputSchemaUpdate.ReadOnly = new Wrapper(
    impl
  )
}
